#!/APSshare/epd/rh6-x86_64/bin/python

import time
import epics

def onChanges(pvname, char_value=None, **kws):
    print " %s now %s" % (pvname, char_value)

pvs = []
for i in range(36):
    me = epics.PV("id%2.2i:shutter" % (i+1))
    me.get(as_string=True)
    me.add_callback(onChanges)
    pvs.append(me)

while True:
    time.sleep(0.01)



#!/APSshare/epd/rh6-x86_64/bin/python

import time
import epics

pvnames = ('id03:dval1', 'id03:dval2', 'id03:dval3',
           'id03:ival1', 'id03:ival2', 'id03:ival3')

pvs = []
for name in pvnames:
    pvs.append(epics.PV(name))

def onChanges(pvname, char_value=None, **kws):
    vals = [p.char_value for p in pvs]
    print time.ctime(),  ' |  '.join(vals)
    
for pv in pvs:
    pv.get()
    pv.add_callback(onChanges)
    
while True:
    time.sleep(0.001)



#!/APSshare/epd/bin/rh6-x86_64/bin/python

import time
import numpy
import pylab

import epics

pv_dwave = epics.PV('id04:dwave')
pv_iwave = epics.PV('id04:iwave')

dwave = pv_dwave.get()
iwave = pv_iwave.get()

x = numpy.arange(len(dwave))

print 'DWave: sum, mean, std-dev = %.4f, %.4f, %.4f ' % (dwave.sum(), dwave.mean(), dwave.std())

pylab.plot(x, dwave)
pylab.show()




#!/APSshare/epd/rh6-x86_64/bin/python

import time
import epics

pvnames = ('id03:dval1', 'id03:dval2', 'id03:dval3',
           'id03:ival1', 'id03:ival2', 'id03:ival3')

pvs = []
for name in pvnames:
    pvs.append(epics.PV(name))

while True:
    time.sleep(1.0)
    vals = []
    for p in pvs:
        vals.append(p.get(as_string=True))

    print time.ctime(),  ' |  '.join(vals)



#!/APSshare/epd/rh6-x86_64/bin/python

import time
import epics

opened_at = {}
integrated_time = {}

def onChanges(pvname, value=None, char_value=None, **kws):
    if value == 0: # shutter closed
        print ' %s closed ' % pvname
        if opened_at[pvname] > 0:
            integrated_time[pvname] += time.time() - opened_at[pvname]
    else:  # shutter opened
        opened_at[pvname] = time.time()
        print ' %s opened ' % pvname
        
pvs = []
for i in range(16):
    pvname = "id%2.2i:shutter" % (i+1)
    opened_at[pvname]     = -1
    integrated_time[pvname] = 0.0
    pvs.append( epics.PV(pvname,  callback=onChanges) )


start_time = time.time()
while (time.time() - start_time ) < 60:
    time.sleep(0.001)

print 'Done collecting data!'

for i in range(16):
    pvname = "id%2.2i:shutter" % (i+1)
    print "%s: %.3f sec" % (pvname, integrated_time[pvname])




#!/APSshare/anaconda/bin/x86_64/bin/python

import time
import epics

class Thing(epics.Device):
    _fields = ('dval1', 'dval2', 'dval3',
               'ival1', 'ival1', 'ival3',
               'mbbo1', 'string1', 'filename')
    
    def __init__(self, prefix):
        epics.Device.__init__(self, prefix,
                              self._fields, delim=':')

t = Thing('id00')
t.filename = '/local/epics/Test.dat'

print 'Thing: filename waveform = ', t.filename
print 'Thing: filename string   = ', t.get('filename', as_string=True)

print 'Thing:  mbbo, dval1, ival1 ', t.mbbo1, t.dval1, t.ival1
print 'Thing:  mbbo as string     ', t.get('mbbo1', as_string=True)

